Enum std::path::PrefixStable
[-] [+]
[src]
pub enum Prefix<'a> {
Verbatim(&'a OsStr),
VerbatimUNC(&'a OsStr, &'a OsStr),
VerbatimDisk(u8),
DeviceNS(&'a OsStr),
UNC(&'a OsStr, &'a OsStr),
Disk(u8),
}Path prefixes (Windows only).
Windows uses a variety of path styles, including references to drive
volumes (like C:), network shared (like \\server\share) and
others. In addition, some path prefixes are "verbatim", in which case
/ is not treated as a separator and essentially no normalization is
performed.
Variants
Methods
impl<'a> Prefix<'a>
fn is_verbatim(&self) -> bool
Determines if the prefix is verbatim, i.e. begins \\?\.