Struct std::path::PathStable
[-] [+]
[src]
pub struct Path {
// some fields omitted
}A slice of a path (akin to str).
This type supports a number of operations for inspecting a path, including
breaking the path into its components (separated by / or \, depending on
the platform), extracting the file name, determining whether the path is
absolute, and so on. More details about the overall approach can be found in
the module documentation.
This is an unsized type, meaning that it must always be used with behind a
pointer like & or Box.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("/tmp/foo/bar.txt"); let file = path.file_name(); let extension = path.extension(); let parent_dir = path.parent(); }use std::path::Path; let path = Path::new("/tmp/foo/bar.txt"); let file = path.file_name(); let extension = path.extension(); let parent_dir = path.parent();
Methods
impl Path
fn new<S: AsRef<OsStr> + ?Sized>(s: &S) -> &Path
Directly wrap a string slice as a Path slice.
This is a cost-free conversion.
Examples
extern crate std; fn main() { use std::path::Path; Path::new("foo.txt"); }use std::path::Path; Path::new("foo.txt");
You can create Paths from Strings, or even other Paths:
use std::path::Path; let s = String::from("bar.txt"); let p = Path::new(&s); Path::new(&p);
fn as_os_str(&self) -> &OsStr
Yields the underlying OsStr slice.
Examples
extern crate std; fn main() { use std::path::Path; let os_str = Path::new("foo.txt").as_os_str(); }use std::path::Path; let os_str = Path::new("foo.txt").as_os_str();
fn to_str(&self) -> Option<&str>
Yields a &str slice if the Path is valid unicode.
This conversion may entail doing a check for UTF-8 validity.
Examples
extern crate std; fn main() { use std::path::Path; let path_str = Path::new("foo.txt").to_str(); }use std::path::Path; let path_str = Path::new("foo.txt").to_str();
fn to_string_lossy(&self) -> Cow<str>
Converts a Path to a Cow<str>.
Any non-Unicode sequences are replaced with U+FFFD REPLACEMENT CHARACTER.
Examples
extern crate std; fn main() { use std::path::Path; let path_str = Path::new("foo.txt").to_string_lossy(); }use std::path::Path; let path_str = Path::new("foo.txt").to_string_lossy();
fn to_path_buf(&self) -> PathBuf
Converts a Path to an owned PathBuf.
Examples
extern crate std; fn main() { use std::path::Path; let path_str = Path::new("foo.txt").to_path_buf(); }use std::path::Path; let path_str = Path::new("foo.txt").to_path_buf();
fn is_absolute(&self) -> bool
A path is absolute if it is independent of the current directory.
On Unix, a path is absolute if it starts with the root, so
is_absoluteandhas_rootare equivalent.On Windows, a path is absolute if it has a prefix and starts with the root:
c:\windowsis absolute, whilec:tempand\tempare not. In other words,path.is_absolute() == path.prefix().is_some() && path.has_root().
Examples
extern crate std; fn main() { use std::path::Path; assert_eq!(false, Path::new("foo.txt").is_absolute()); }use std::path::Path; assert_eq!(false, Path::new("foo.txt").is_absolute());
fn is_relative(&self) -> bool
A path is relative if it is not absolute.
Examples
extern crate std; fn main() { use std::path::Path; assert!(Path::new("foo.txt").is_relative()); }use std::path::Path; assert!(Path::new("foo.txt").is_relative());
fn prefix(&self) -> Option<Prefix>
Returns the prefix of a path, if any.
Prefixes are relevant only for Windows paths, and consist of volumes
like C:, UNC prefixes like \\server, and others described in more
detail in std::os::windows::PathExt.
fn has_root(&self) -> bool
A path has a root if the body of the path begins with the directory separator.
On Unix, a path has a root if it begins with
/.On Windows, a path has a root if it:
- has no prefix and begins with a separator, e.g.
\\windows - has a prefix followed by a separator, e.g.
c:\windowsbut notc:windows - has any non-disk prefix, e.g.
\\server\share
- has no prefix and begins with a separator, e.g.
Examples
extern crate std; fn main() { use std::path::Path; assert!(Path::new("/etc/passwd").has_root()); }use std::path::Path; assert!(Path::new("/etc/passwd").has_root());
fn parent(&self) -> Option<&Path>
The path without its final component, if any.
Returns None if the path terminates in a root or prefix.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("/foo/bar"); let foo = path.parent().unwrap(); assert!(foo == Path::new("/foo")); let root = foo.parent().unwrap(); assert!(root == Path::new("/")); assert!(root.parent() == None); }use std::path::Path; let path = Path::new("/foo/bar"); let foo = path.parent().unwrap(); assert!(foo == Path::new("/foo")); let root = foo.parent().unwrap(); assert!(root == Path::new("/")); assert!(root.parent() == None);
fn file_name(&self) -> Option<&OsStr>
The final component of the path, if it is a normal file.
If the path terminates in ., .., or consists solely or a root of
prefix, file_name will return None.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("hello_world.rs"); let filename = "hello_world.rs"; assert_eq!(filename, path.file_name().unwrap()); }use std::path::Path; let path = Path::new("hello_world.rs"); let filename = "hello_world.rs"; assert_eq!(filename, path.file_name().unwrap());
fn relative_from<'a, P: ?Sized + AsRef<Path>>(&'a self, base: &'a P) -> Option<&Path>
Returns a path that, when joined onto base, yields self.
If base is not a prefix of self (i.e. starts_with
returns false), then relative_from returns None.
fn starts_with<P: AsRef<Path>>(&self, base: P) -> bool
Determines whether base is a prefix of self.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("/etc/passwd"); assert!(path.starts_with("/etc")); }use std::path::Path; let path = Path::new("/etc/passwd"); assert!(path.starts_with("/etc"));
fn ends_with<P: AsRef<Path>>(&self, child: P) -> bool
Determines whether child is a suffix of self.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("/etc/passwd"); assert!(path.ends_with("passwd")); }use std::path::Path; let path = Path::new("/etc/passwd"); assert!(path.ends_with("passwd"));
fn file_stem(&self) -> Option<&OsStr>
Extracts the stem (non-extension) portion of self.file().
The stem is:
- None, if there is no file name;
- The entire file name if there is no embedded
.; - The entire file name if the file name begins with
.and has no other.s within; - Otherwise, the portion of the file name before the final
.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("foo.rs"); assert_eq!("foo", path.file_stem().unwrap()); }use std::path::Path; let path = Path::new("foo.rs"); assert_eq!("foo", path.file_stem().unwrap());
fn extension(&self) -> Option<&OsStr>
Extracts the extension of self.file(), if possible.
The extension is:
- None, if there is no file name;
- None, if there is no embedded
.; - None, if the file name begins with
.and has no other.s within; - Otherwise, the portion of the file name after the final
.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("foo.rs"); assert_eq!("rs", path.extension().unwrap()); }use std::path::Path; let path = Path::new("foo.rs"); assert_eq!("rs", path.extension().unwrap());
fn join<P: AsRef<Path>>(&self, path: P) -> PathBuf
Creates an owned PathBuf with path adjoined to self.
See PathBuf::push for more details on what it means to adjoin a path.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("/tmp"); let new_path = path.join("foo"); }use std::path::Path; let path = Path::new("/tmp"); let new_path = path.join("foo");
fn with_file_name<S: AsRef<OsStr>>(&self, file_name: S) -> PathBuf
Creates an owned PathBuf like self but with the given file name.
See PathBuf::set_file_name for more details.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("/tmp/foo.rs"); let new_path = path.with_file_name("bar.rs"); }use std::path::Path; let path = Path::new("/tmp/foo.rs"); let new_path = path.with_file_name("bar.rs");
fn with_extension<S: AsRef<OsStr>>(&self, extension: S) -> PathBuf
Creates an owned PathBuf like self but with the given extension.
See PathBuf::set_extension for more details.
Examples
extern crate std; fn main() { use std::path::{Path, PathBuf}; let path = Path::new("/tmp/foo.rs"); let new_path = path.with_extension("txt"); assert_eq!(new_path, PathBuf::from("/tmp/foo.txt")); }use std::path::{Path, PathBuf}; let path = Path::new("/tmp/foo.rs"); let new_path = path.with_extension("txt"); assert_eq!(new_path, PathBuf::from("/tmp/foo.txt"));
fn components(&self) -> Components
Produce an iterator over the components of the path.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("/tmp/foo.rs"); for component in path.components() { println!("{:?}", component); } }use std::path::Path; let path = Path::new("/tmp/foo.rs"); for component in path.components() { println!("{:?}", component); }
fn iter(&self) -> Iter
Produce an iterator over the path's components viewed as OsStr slices.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("/tmp/foo.rs"); for component in path.iter() { println!("{:?}", component); } }use std::path::Path; let path = Path::new("/tmp/foo.rs"); for component in path.iter() { println!("{:?}", component); }
fn display(&self) -> Display
Returns an object that implements Display for safely printing paths
that may contain non-Unicode data.
Examples
extern crate std; fn main() { use std::path::Path; let path = Path::new("/tmp/foo.rs"); println!("{}", path.display()); }use std::path::Path; let path = Path::new("/tmp/foo.rs"); println!("{}", path.display());